@@ -52,12 +52,14 @@ namespace larcv3 {
   /// Used as an invalid value identifier for double-point precision
   const double             kINVALID_DOUBLE    = std::numeric_limits< double             >::max();
   /// Used as an invalid value identifier for signed long precision
-  const double             kINVALID_LONG      = std::numeric_limits< long               >::max();
+  const long               kINVALID_LONG      = std::numeric_limits< long               >::max();
 
   /// Namespace for larcv3 message related types
   namespace msg {
 
-    /// Message level
+    /**
+     * @brief      Message Level
+     */
     enum Level_t { kDEBUG, kINFO, kNORMAL, kWARNING, kERROR, kCRITICAL, kMSG_TYPE_MAX };
 
     /// Formatted message prefix per message level
