@@ -1,7 +1,7 @@
 /**
  * \file IOManager.h
  *
- * \ingroup core_DataFormat
+ * \ingroup DataFormat
  *
  * \brief Class def header for a class larcv3::IOManager
  *
@@ -9,7 +9,7 @@
  * @author coreyjadams
  */
 
-/** \addtogroup core_DataFormat
+/** \addtogroup DataFormat
 
     @{*/
 #ifndef __LARCV3DATAFORMAT_IOMANAGER_H
@@ -28,7 +28,6 @@
 
 #include "larcv3/core/base/larcv_base.h"
 #include "larcv3/core/base/larbys.h"
-#include "larcv3/core/base/PSet.h"
 #include "larcv3/core/dataformat/EventBase.h"
 #include "larcv3/core/dataformat/EventID.h"
 
@@ -50,24 +49,23 @@ namespace larcv3 {
     /// Default constructor
     IOManager(IOMode_t mode = kREAD, std::string name = "IOManager");
 
-    /// Configuration PSet construction so you don't have to call setter functions
-    IOManager(const PSet& cfg);
+    /// Configuration json construction so you don't have to call setter functions
+    IOManager(const json& cfg);
+    void configure(const json& cfg);
 
-    /// Configuration PSet file construction so you don't have to call setter functions
-    IOManager(std::string config_file, std::string name = "IOManager");
+    json get_config(){return config;}
 
     /// Destructor
     ~IOManager();
     /// IO mode accessor
-    IOMode_t io_mode() const { return _io_mode;}
+    IOMode_t io_mode() const { return config["IOMode"].get<IOMode_t>();}
     void reset();
-    void add_in_file(const std::string filename, const std::string dirname = "");
+    void add_in_file(const std::string filename);
     void clear_in_file();
     void set_core_driver(const bool opt = true);
     void set_out_file(const std::string name);
     ProducerID_t producer_id(const ProducerName_t& name) const;
     std::string product_type(const size_t id) const;
-    void configure(const PSet& cfg);
     bool initialize(int color=0);
     bool read_entry(const size_t index, bool force_reload = false);
     bool save_entry();
@@ -80,7 +78,7 @@ namespace larcv3 {
     { return _out_entries;}
 
     std::string get_file_out_name() const
-    { return _out_file_name;}
+    { return config["Output"]["OutFileName"];}
 
     size_t get_n_entries() const
     { return (_in_entries_total ? _in_entries_total : _out_entries); }
@@ -112,10 +110,7 @@ namespace larcv3 {
       return * std::dynamic_pointer_cast<T> (ptr);
     }
 
-    const EventID& event_id() const {
-        if (_set_event_id.valid() ) return _set_event_id;
-        return _event_id ;
-     }
+    const EventID& event_id() const;
 
     const EventID& last_event_id() const { return _last_event_id; }
 
@@ -138,10 +133,28 @@ namespace larcv3 {
       return res;
     }
 
-    const std::vector<std::string>& file_list() const
-    { return _in_file_v; }
-
+    const std::vector<std::string> file_list() const
+    { return config["Input"]["InputFiles"].get<std::vector<std::string> >(); }
 
+    static json default_config(){
+        json c = {
+            {"Verbosity", logger::default_level()},
+            {"IOMode", kREAD},
+            {"Input" , {
+                {"InputFiles", std::vector<std::string>()},
+                {"UseH5CoreDriver", false},
+                {"ReadOnlyName", std::vector<std::string>()},
+                {"ReadOnlyType", std::vector<std::string>()},
+            }},
+            {"Output", {
+                {"OutFileName", ""},
+                {"Compression", 1},
+                {"StoreOnlyName", std::vector<std::string>()},
+                {"StoreOnlyType", std::vector<std::string>()},
+            }},
+        };
+        return c;
+    }
 
   protected:
     void   set_id();
@@ -156,6 +169,10 @@ namespace larcv3 {
     // Closes the objects currently open in file with id fid
     int close_all_objects(hid_t fid);
 
+    // Default configuration for IO manager:
+    json config;
+
+
     // The hdf5 model enforces the same number of entries per group,
     // since the entry list is defined per file.
 
@@ -163,10 +180,7 @@ namespace larcv3 {
     // Files are checked for consistency in which groups are present.
 
     // General Parameters
-    IOMode_t    _io_mode;
     bool        _prepared;
-    // This can override the compression level across the entire file:
-    uint _compression_override;
 
 
     // Parameters controlling output file large scale tracking:
@@ -176,8 +190,7 @@ namespace larcv3 {
     size_t      _out_index;
     // Total output entries
     size_t      _out_entries;
-    // Name of the output file
-    std::string _out_file_name;
+
 
     // Parameters controllign input file large scale tracking:
     // Current index in the input files
@@ -187,14 +200,10 @@ namespace larcv3 {
     size_t      _in_entries_total;
     // Index of currently active file
     size_t      _in_active_file_index;
-    // List of input file names:
-    std::vector<std::string>        _in_file_v;
-    // List of input directory names:
-    std::vector<std::string>        _in_dir_v;
     // Currently open file:
     hid_t       _in_open_file;
     // List of total entries in input files
-    std::vector<size_t>             _in_entries_v;
+    std::vector<size_t> _in_entries_v;
 
     // Parameters for the event ID management:
     EventID   _event_id;
@@ -240,7 +249,6 @@ namespace larcv3 {
     std::map<std::string,std::set<std::string> > _read_only;
     std::vector<bool> _store_id_bool;
     std::vector<bool> _read_id_bool;
-    bool _h5_core_driver;
 
 
     // IOManager has to control the EventID dataset it's self for the output file.
@@ -251,6 +259,7 @@ namespace larcv3 {
     // Internal bookkeeping for when the input file switches:
     bool _force_reopen_groups;
 
+
     // MPI Variables:
 #ifdef LARCV_MPI
 
