@@ -152,8 +152,6 @@ void init_particle(pybind11::module m){
     pybind11::class_<larcv3::Particle> particle(m, "Particle");
 
     particle.doc() = R"pbdoc(
-    Particle
-    =========
 
     A Particle represents an abstract label more relevant to experimental data.  Typically created 
     from simulation data, there are fields to hold a variety of per-particle information as well as 
